#
# utf8_filenames.py <Peter.Bienstman@UGent.be>
#

# In some cases, Python 3.5 in Crystax seems to set sys.setdefaultencoding() to
# "ascii", although the Android filesystem supports UTF-8. Therefore, we wrap
# all builtin functions to encode the filenames.

import os
import builtins

def open(filename, *a, **kw):
    try:
        return builtins.open(filename, *a, **kw)
    except:
        filename = filename.encode("utf-8") if type(filename) == str else filename
        return builtins.open(filename, *a, **kw)

_os_path_exists_orig = os.path.exists
def os_path_exists_utf8(filename, *a, **kw):
    try:
        return _os_path_exists_orig(filename, *a, **kw)
    except:
        filename = filename.encode("utf-8") if type(filename) == str else filename
        return _os_path_exists_orig(filename, *a, **kw)
os.path.exists = os_path_exists_utf8

_os_path_getsize_orig = os.path.getsize
def os_path_getsize_utf8(filename, *a, **kw):
    try:
        return _os_path_getsize_orig(filename, *a, **kw)
    except:
        filename = filename.encode("utf-8") if type(filename) == str else filename
        return _os_path_getsize_orig(filename, *a, **kw)
os.path.getsize = os_path_getsize_utf8

_os_makedirs_orig = os.makedirs
def os_makedirs_utf8(filename, *a, **kw):
    try:
        return _os_makedirs_orig(filename, *a, **kw)
    except:
        filename = filename.encode("utf-8") if type(filename) == str else filename
        return _os_makedirs_orig(filename, *a, **kw)
os.makedirs = os_makedirs_utf8




#
# export_to_pdf.py <Peter.Bienstman@UGent.be>
#

# Quick and dirty script to export the latest 100 Arabic cards to a pdf file
# Requires unoconv from libreoffice.

# 'data_dir = None' will use the default sysem location, edit as appropriate.
data_dir = None
cards_to_export = 100
text_in_tag = "Arabic"

import os

from mnemosyne.script import Mnemosyne
mnemosyne = Mnemosyne(data_dir)

f = file("mnemosyne.txt", "w")
    
_fact_ids = []
count = 0
for cursor in mnemosyne.database().con.execute(\
    """select _id, _fact_id from cards order by creation_time desc"""):
    card = mnemosyne.database().card(cursor[0], is_id_internal=True)
    if card.fact._id not in _fact_ids and text_in_tag in card.tag_string():
        count += 1
        if count == cards_to_export:
            break
        _fact_ids.append(card.fact._id )
        q = card.question(render_chain="plain_text").encode("utf-8")
        a = card.answer(render_chain="plain_text").encode("utf-8")
        # We write the answer first to have alignment in columns
        # (Arabic is not monospace).
        print(a + (40-len(a))*" " + q, file=f)
f.close()

os.system("unoconv mnemosyne.txt")

mnemosyne.finalise()
